@@ -14,7 +14,7 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-"""Import a Debian source package into a git repository"""
+"""Import a Debian source package into a GIT repository"""
 
 import ConfigParser
 import sys
@@ -26,8 +26,8 @@ import glob
 import pipes
 import time
 import gbp.command_wrappers as gbpc
-from gbp.pkg import UpstreamSource
 from gbp.deb.dscfile import DscFile
+from gbp.deb.upstreamsource import DebianUpstreamSource
 from gbp.deb.git import (DebianGitRepository, GitRepositoryError)
 from gbp.deb.changelog import ChangeLog
 from gbp.git import rfc822_date_to_git
@@ -328,7 +328,7 @@ def main(argv):
                 set_bare_repo_options(options)
 
             dirs['tmp'] = os.path.abspath(tempfile.mkdtemp(dir='..'))
-            upstream = UpstreamSource(src.tgz)
+            upstream = DebianUpstreamSource(src.tgz)
             upstream.unpack(dirs['tmp'], options.filters)
 
             format = [(options.upstream_tag, "Upstream"), (options.debian_tag, "Debian")][src.native]
