@@ -153,6 +153,8 @@ class ComponentTestBase(object):
             self._loghandler = gbp.log.GbpStreamHandler(self._log, False)
             self._loghandler.addFilter(gbp.log.GbpFilter([gbp.log.WARNING,
                                                           gbp.log.ERROR]))
+            for hdl in gbp.log.LOGGER.handlers:
+                gbp.log.LOGGER.removeHandler(hdl)
             gbp.log.LOGGER.addHandler(self._loghandler)
         elif self._log is not None:
             gbp.log.LOGGER.removeHandler(self._loghandler)
